package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`/@`!````P"4``#0```!(L0```````#0`(``-
M`"@`'0`<``8````T````-````#0```"@`0``H`$```0````$`````P```!0"
M```4`@``%`(``!H````:````!`````$````!````````````````````R!$`
M`,@1```$`````!````$`````(````"`````@``!%/@``13X```4`````$```
M`0````!@````8````&```"1(```D2```!``````0```!````N*P``+B\``"X
MO```8`,``*`#```&`````!````(```#TK```]+P``/2\`````0````$```8`
M```$````!````-0!``#4`0``U`$``$````!`````!`````0````$````!*@`
M``2H```$J```(````"`````$````!````%/E=&3X`0``^`$``/@!```<````
M'`````0````$````4.5T9+"@``"PH```L*```/P```#\````!`````0```!1
MY71D```````````````````````````&````$````%+E=&2XK```N+P``+B\
M``!(`P``2`,```0````!````!````!0````#````1TY5`/I_#Y9%L9EU9%>@
M4"`OAR!],6T2!`````P````%````1TY5``*``,`$`````0```"]L:6)X,S(O
M;&0M;&EN=7@M>#,R+G-O+C(````1````/@````@````(`````!P0!"5`!((H
M```$H(8`A("!``)+*`0H.(`30XH`!`@`````/@```$$```!$````10```$X`
M``!/````40````````!4````50```%8```!8````6@```%P`````````````
M`&[%WQ_.WD<M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'
MPN4_++KCDGSRV],=^J%L8)E/PYMK"4/69J_,9L6YG$`X\HL<0D75[(D'<-,S
M8MOM%8PES`PZEPNGW:-KT&7.;7^IG)O@IP(*:QJ>4`J*$%>CX/M)````````
M`````````````*8!`````````````!(```"+`@`````````````2````Y```
M````````````$@```+,!`````````````!(```"6```````````````2````
M70$`````````````$@```,`"`````````````!(```#I```````````````2
M````Q`$`````````````$@```/H``````````````!(```":`@``````````
M```2`````0``````````````(````.,!`````````````!(```"3`@``````
M```````2````S0$`````````````$@```"L!`````````````!(````;`0``
M```````````2````KP(`````````````$@```"D"`````````````!(````-
M`0`````````````2````E0$`````````````$@```!```````````````"``
M``![`0`````````````2````+```````````````(````.L!````````````
M`!(```!.`@`````````````2````1@``````````````$@```&,`````````
M`````!8```!-`0`````````````2````=@``````````````$@```'X#````
M`````````!(```#4`0`````````````2````TP``````````````$@```(<`
M`````````````!(```"A`@`````````````2````&0(`````````````$@``
M`*@"`````````````!(```"W```````````````2````A`(`````````````
M$@````0"`````````````!(```"]`0`````````````2````;@(`````````
M````$@```#\!`````````````!(```#R`0`````````````2````[@``````
M````````$@```/D!`````````````!(````Q`@`````````````2````30(`
M````````````$@```/\!`````````````!(```#2`@`````````````2````
M/P(`````````````$@```*(``````````````!(```#<`0`````````````2
M````:`$`````````````$@````H"`````````````!(```!T`0``````````
M```2````JP$`````````````$@```#0!`````````````!(```!4````````
M```````2````50(`````````````$@```"`"`````````````!(```"'`P``
MT$$``+X````2``X`W`,``*`X```,!P``$@`.`&("``"@(P``'`(``!(`#@#^
M`@``D"T```D````2``X`'`,``+`_```>`@``$@`.``($``"@+0```P(``!(`
M#@#"`P``(,`````````0`!H`#P,``+`O```B````$@`.`#(#``!@-0``80``
M`!(`#@"3`P```&````0````1`!``KP,``&!9``#&`0``$@`.`+H#``"P+```
M+0```!(`#@#7`P``6,`````````0`!H`A@$``."\```3````$0`6`/`#``#0
M-P``Q0```!(`#@`9!```T#4``+`````2``X`H@,```#`````````$``9`%8#
M``#@+P``*0$``!(`#@#(`@``(,````0````1`!H`9P(``$#````$````$0`:
M`.D#```8P````````!``&0`/!```%,````0````1`!D`J`,``,`E```D````
M$@`.`,X#```060``3````!(`#@"D`P```,`````````@`!D`R@(``"#````$
M````(0`:`'4"`````````````"(```!L`P``H#<``"(````2``X`0`,``.`L
M``"N````$@`.`&(#```P6P``]0(``!(`#@#&````1,````$````1`!H`(00`
M`!`Q``!&!```$@`.``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y
M<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T
M9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R
M;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E
M<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,
M7VUE;6]R>5]W<F%P`%]?<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E
M861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK
M`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D`&UK9&ER`%]?=F9P
M<FEN=&9?8VAK`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C
M:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T
M9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&]P96YD:7(`9V5T
M=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`<W1R
M;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`;&EB<&5R;"YS;RXU
M+C0P`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?
M9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA
M7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P
M871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI=%]E
M;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,38``````@`"``$`
M`@`!``$``@`"``(``0`"``$``@`"``(``0`!``(``@`!``(``0`!``$``@`#
M``$``0`!``$``@`"``$``0`"``(``@`!``(``@`"``(``0`"``$``@`"``,`
M`@`"``(``0`"``$``@`"``(``0`!``0``@`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`"``(``0`!``$``0`!``(``@`!``$``0`!``$`
M`0`#`/0"```0`````````+21E@8```0`+@0``!````"SD98&```#`#D$```0
M````EI&6!@```@!$!````````+B\```(````H"8``+R\```(````8"8``,"\
M```(````3F$``,2\```(````!F$``,B\```(````Z6```,R\```(````7V$`
M``3````(````!,```!3````(````^&(``+B_```&6````````,"_```&"@``
M`````,B_```&#````````-"_```&%@```````-B_```&&````````."_```2
M'````````.B_```&'0```````/"_```&'@```````/B_```&/````````."\
M```%2P```````"#````%4````````$#````%40```````$3````%7```````
M`!"^```'`0```````!B^```'`@```````""^```'`P```````"B^```'!```
M`````#"^```'!0```````#B^```'!@```````$"^```'!P```````$B^```'
M"````````%"^```'"0```````%B^```'"P```````&"^```'#0```````&B^
M```'#@```````'"^```'#P```````'B^```'$````````("^```'$0``````
M`(B^```'$@```````)"^```'$P```````)B^```'%````````*"^```'%0``
M`````*B^```'%P```````+"^```'&0```````+B^```'&@```````,"^```'
M&P```````,B^```''P```````-"^```'(````````-B^```'(0```````."^
M```'(@```````.B^```'(P```````/"^```')````````/B^```')0``````
M``"_```')@````````B_```')P```````!"_```'*````````!B_```'*0``
M`````""_```'*@```````"B_```'*P```````#"_```'+````````#B_```'
M+0```````$"_```'+@```````$B_```'+P```````%"_```',````````%B_
M```',0```````&"_```',@```````&B_```',P```````'"_```'-```````
M`'B_```'-0```````("_```'-@```````(B_```'-P```````)"_```'.```
M`````)B_```'.0```````*"_```'.@```````*B_```'.P```````+"_```'
M/0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%O9\``$B%P'0"_]!(@\0(PP```````````/\UVIT``/\EW)T`
M``\?0`#_)=J=``!H`````.G@_____R72G0``:`$```#IT/____\ERIT``&@"
M````Z<#_____)<*=``!H`P```.FP_____R6ZG0``:`0```#IH/____\ELIT`
M`&@%````Z9#_____):J=``!H!@```.F`_____R6BG0``:`<```#I</____\E
MFIT``&@(````Z6#_____)9*=``!H"0```.E0_____R6*G0``:`H```#I0/__
M__\E@IT``&@+````Z3#_____)7J=``!H#````.D@_____R5RG0``:`T```#I
M$/____\E:IT``&@.````Z0#_____)6*=``!H#P```.GP_O___R5:G0``:!``
M``#IX/[___\E4IT``&@1````Z=#^____)4J=``!H$@```.G`_O___R5"G0``
M:!,```#IL/[___\E.IT``&@4````Z:#^____)3*=``!H%0```.F0_O___R4J
MG0``:!8```#I@/[___\E(IT``&@7````Z7#^____)1J=``!H&````.E@_O__
M_R42G0``:!D```#I4/[___\E"IT``&@:````Z4#^____)0*=``!H&P```.DP
M_O___R7ZG```:!P```#I(/[___\E\IP``&@=````Z1#^____)>J<``!H'@``
M`.D`_O___R7BG```:!\```#I\/W___\EVIP``&@@````Z>#]____)=*<``!H
M(0```.G0_?___R7*G```:"(```#IP/W___\EPIP``&@C````Z;#]____);J<
M``!H)````.F@_?___R6RG```:"4```#ID/W___\EJIP``&@F````Z8#]____
M):*<``!H)P```.EP_?___R6:G```:"@```#I8/W___\EDIP``&@I````Z5#]
M____)8J<``!H*@```.E`_?___R6"G```:"L```#I,/W___\E>IP``&@L````
MZ2#]____)7*<``!H+0```.D0_?___R5JG```:"X```#I`/W___\E8IP``&@O
M````Z?#\____)5J<``!H,````.G@_/___R52G```:#$```#IT/S___\E2IP`
M`&@R````Z<#\____)4*<``!H,P```.FP_/___R4ZG```:#0```#IH/S___\E
M,IP``&:0````````````````````````````````\P\>^E53@^PHB7PD#(U\
M)`R)="0(C70D"(E4)`1DBQ0E&````(E4)!R-5"0$Z([___^+->B;``"+/1*<
M``!(B?+H2CH``(`]5YP````/A!H!``!(BP7FFP``9(L4)0````"+?"0,9XL$
M`HU?`X/'!&>`B#8#```#@?____\_#X=K`0``P><"Z.3^__]$BTPD"$2+1"0,
M2(G!B041G```B<=G08L!9XD!C069/0``9XE!!(L%O)L``&>)00B-!8@]``!G
MB4$,08/X`0^.,@$``+H!````9F8N#Q^$``````!G08LTD6>)=)<,@\(!03G0
M=>Y!@\`#9T+'!(<`````BSVOFP``13'`B=J--;`'``#HR_O__X7`#X2.````
MBSV1FP``C5PD&.B4_?__2(G>C3W..P``B<4QP.CB`0``2(7`='B+/6N;``#H
M8OO__^B=_/__BT0D'&0K!"48````#X6R````@\0HB>A;7</H3OS__XD%/)L`
M`$B)QX7`#X2*````Z*C\__](BP6QF@``9(L4)0````")P0'19XL)9\:!Y@4`
M``#IM_[__XL]`YL``.BJ^___Z6+___^+/>N:``"%_W0*Z&8<``#I=/___XT]
MXSH``$B)WNA#`0``B07)F@``B<>%P`^$5O___^O6C35+EP``C3VX.@``,<#H
M3OW__T&X!````.GI_O__OP$```#H>?K__^B4^___#Q]``#'M08G1BS0D@\0$
MB>*#Y/!05$4QP#')C3W#_?___Q45F@``]&8N#Q^$``````!FD(T](IH``(T%
M')H``#GX=!"+!<J9``"%P'0&B<#_X&:0PV9F+@\?A```````#Q]``(T]\ID`
M`(TU[)D``"G^B?#![A_!^`(!QM'^=!2+!9:9``"%P'0*B<#_X&8/'T0``,-F
M9BX/'X0```````\?0`#S#Q[Z@#W:F0```'4K58L%1)D``(GEA<!T"XL]A)D`
M`.C[_/__Z&;____&!;29```!7<,/'T0``,,/'X``````\P\>^NEW____9BX/
M'X0``````&8N#Q^$```````/'P!!5T%6055!5%53@^P(1(LE3)D``$6%Y`^$
ME@```&</M@=(B?U)B?6$P'0$/#UU43';9T6+-"1%A?9T+$6)YV:01(GWB=I(
MB>[H@_G__X7`=0AG08`\'CUT1V=%BW<$08/'!$6%]G79@\0(1(GP6UU!7$%=
M05Y!7\,/'X0``````(G[9P^V0P&#PP&$P'0$/#UU\"GKZYMF+@\?A```````
M12GG18UT'@%!P?\"9T6)?0#KM$4Q]NNO#Q^$``````!3@>R@````9(L<)1@`
M``")G"2<````2(G[B>;H$/O__X7`=32+5"08@>(`\```@?H`0```=`B!^@"@
M``!U'+X"````2(G?Z/7X__^%P`^4P`^VP.L%#Q\`,<"+E"2<````9"L4)1@`
M``!U"('$H````%O#Z%CY__\/'X0``````$%505154X'LJ````&2+!"48````
MB80DG````#'`2(7_=`EG@#\`2(G[=26+A"2<````9"L$)1@````/A0\!``"!
MQ*@```!;74%<05W##Q\`Z.OW__]!B<2%P'3/3(GGZ/SW__^%P`^$I````&>`
M>!,NC6@3=0IG@'T!`'3?#Q\`9X!X$RX/A)T```!(B=_HW?G__TB)[T&)Q>C2
M^?__08U\!0+HB/K__TF)Z4F)V+K_____28G%2(G'C0U%-P``,<"^`0```.C5
M^?__3(GOB>;HJ_C__TR)[X/X_W00BT0D&"4`\```/0!```!T6^@.^O__3(GO
MZ*;W__],B>?H7O?__X7`#X5B____9@\?1```3(GGZ)CW__](B=_H</G__^D&
M____#Q\`9X!]`2X/A5C___]G@'T"``^$'O___^E(____#Q]$``#HL_[__^NC
MZ/SW__]F9BX/'X0``````)!!5T%6055!5%5(B?U3@^PH9X`^/62+'"48````
MB5PD'$B)\W4#@\,!2(G?Z.#X__](B>^-="0808G$,<#H'_W__TB)QT&)Q87`
M#X0)`0``Z+SX__]$.>`/@]L```"+1"081(T\A0````!G#[9%`(3`#X2:`0``
M/#T/A)(!``")Z&</ME`!@\`!A-)T!8#Z/77O*>A$BRTFE@``0HU\(`+H+/G_
M_T4!_6=!B44`A<!T88L%"I8``(U-`6="BQ0X9P^V10!GB`(\/70LA,!U%NLF
M9F8N#Q^$```````/'T0``#P]=!*#P0&#P@%G#[9!_V>(`H3`=>IGQ@(],<`/
M'T``9P^V#!AGB$P"`8/``83)=>^+1"0<9"L$)1@````/A0$!``"#Q"A;74%<
M05U!7D%?PP\?@``````QP&8/'T0``&</MA089T&(5`4`@\`!A-)U[NN]#Q]`
M`$2+-6&5``!G08L.A<D/A*P```!%,>UFD$2)Z$&#Q0%G0XL4KH72=?"--(4,
M````BP5;E0``A<!U5\<%394```$```")]^@N^/__B40D#(7`#X1C____1HT\
MK0````!$B?9(B<=$B?KHK/7__T2+1"0,B07QE```9T/'1*@$`````$2);"08
MZ8;^__\/'T0``$2)]^C@]?__B07*E```08G`A<`/A!#___]&C3RM`````.O$
M#Q]$```QP.E\_O__O@@```!%,>WI8____^C']?__#Q^``````$%5NO\/``!!
M5%5(B?V-/6<T``!3@>P8$```9$2+)"48````1(FD)`P0``!)B?2)YDF)]>BH
M]___A<!^$8G#C4#_9X!\'/\`=4>%P'4[9(L$)0````!,B>)(B>Y``P7NDP``
M9XLXZ$;U__^+A"0,$```9"L$)1@```!U2H'$&!```%M=05Q!7<.)PV8/'T0`
M`(G:OB\```!,B>_H(?;__TB%P'2I9(L$)0````")V4R)ZDB)[D`#!963``!G
MBSCHO?7__^NEZ/;T__]F#Q]$``#S#Q[Z4V2+'"4`````C0W]<P``C36@,P``
M0`,=8),``(L58I,``&>+.^C"]O__9XL[13')6XT-*34``(T5#Q,``$F)R(TU
MBS,``.D1]?__D/,/'OIDBP0E`````$`#!1V3``"-#:=S``"--4HS``!GBSB+
M%1"3``#I<_;__P\?`/,/'OI!5%4Q[5.!["`@``!DBP0E&````(F$)!P@```Q
MP(GC1(VD)!`0``#HX/3__T2-#?XR``"-#2TS``!(B=]!B<"Z`1```+X!````
M,<#H;/7__[H`$```3(GF2(G?Z"SV__^%P'@CC7@!B</HWO7__TB)QXG%A<!T
M$(G:3(GFZ'OT__]GQD0=``")Z(N4)!P@``!D*Q0E&````'4+@<0@(```6UU!
M7,/HPO/__V:0\P\>^NE'____#Q^``````/,/'OI!5T%6055!5$F)]%5(B?V-
M/9\R``!3@>S($```9(L$)1@```")A"2\$```,<"-="0<Z.;X__^^+P```$B)
M[XG#Z#?T__](A<!T0DB)[HT]:C(``#'`Z&+[__^)Z(N4)+P0``!D*Q0E&```
M``^%B0$``('$R!```%M=05Q!74%>05_#9BX/'X0``````$R)YT2-+30R``#H
M`?3__TR)[DB)Q^@F\___C8PDL````(E,)`B-3"0@08G&B4PD#(7`=(IG08`^
M``^$U0```)!%B?2%VW02B=],B>;H?_/__X7`#X2;````3(GGZ-_S__]!C50&
M_T&)QT$YUG(.ZQUGQ@(`@^H!03G6=`9G@#HO=.Y,B>?HMO/__T&)QTB)[^BK
M\___08U$!P$]_P\```^'&?___T2+9"0(@^P(N@`0```QP%6-#8DR``!%B?"^
M`0```$2-#78Q``!,B>?HGO/__XMT)!Q,B>?H<O+__UI9A<!U$(M$)#@E`/``
M`#T`@```=$Q,B>XQ_^A"\O__08G&A<`/A+7^__]G08`^``^%+/___X7;=`9G
M@#LN=!)!OP$```!$C37[,```Z5W___]G@'L!`'2]Z^4/'X``````O@$```!,
MB>?H0_'__X7`=:-,B>:-/=<P``#HT?G__TR)Y^BI\O__B<7I8/[__^BM\?__
M9F8N#Q^$``````!FD/,/'OI3OB\```!(B?OH[O'__XU0`87`B=</1/M;Z6[R
M__]F9BX/'X0```````\?`/,/'OI54X'L&!```&2+!"48````B80D#!```#'`
M2(7_#X3*````9X`_`$B)^P^$O0```.A8\O__C5`!@?H`$```#X?9````B>6)
MYX/Z"'(-B=&)WL'I`V?S2*6)\S')]L($=`MGBPMGB0^Y!````/;"`G0/9T0/
MMP0+9V9$B00/@\$"@^(!=`EG#[84"V>(%`^-1`7_.<5R$NL6#Q]$``!GQ@``
M@^@!.>AT!F>`."]T[XGOOB\```#H$_'__X7`="\YQ7)3B>_HE/'__XG`BY0D
M#!```&0K%"48````=46!Q!@0``!;7<,/'X0``````(N$)`P0``!D*P0E&```
M`'4C@<08$```C3UI+P``6UWI3/'__P\?0`!GQ@``ZZ=FD#'`ZZCH1_#__P\?
M@`````#S#Q[Z05=!5D%5051$C25/+P``55.#["ADBRPE&````(EL)!R-;"08
M2(GK#Q]$```QP$B)[DR)Y^AS]?__2(7`="Z+5"08BP7$C@``C0209XM0!&>)
M$(72=-9F#Q]$``!GBU`(@\`$9XD0A=)U\NO`1(TE]"X``(G=#Q^``````#'`
M2(GN3(GGZ"/U__](A<!T+HM4)!B+!72.``"-!)!GBU`$9XD0A=)TUF8/'T0`
M`&>+4`B#P`1GB1"%TG7RZ\!$C26L+@``B=T/'X``````,<!(B>Y,B>?HT_3_
M_TB%P'0NBU0D&(L%)(X``(T$D&>+4`1GB1"%TG369@\?1```9XM0"(/`!&>)
M$(72=?+KP$2-)64N``")W0\?@``````QP$B)[DR)Y^B#]/__2(7`="Z+5"08
MBP74C0``C0209XM0!&>)$(72=-9F#Q]$``!GBU`(@\`$9XD0A=)U\NO`C2T=
M+@``08G<#Q^``````#'`3(GF2(GOZ#/T__](A<!T+HM4)!B+!82-``"-!)!G
MBU`$9XD0A=)TUF8/'T0``&>+4`B#P`1GB1"%TG7RZ\!$C2W<+0``08G<9@\?
M1```,<!,B>9,B>_HX_/__TB%P'0NBU0D&(L%-(T``(T$D&>+4`1GB1"%TG36
M9@\?1```9XM0"(/`!&>)$(72=?+KP$2-)4$M``!!B=UF#Q]$```QP$R)[DR)
MY^B3\___2(7`="Z+5"08BP7DC```C0209XM0!&>)$(72=-9F#Q]$``!GBU`(
M@\`$9XD0A=)U\NO`1(TU2"T``$&)W68/'T0``#'`3(GN3(GWZ$/S__](A<!T
M+HM4)!B+!92,``"-!)!GBU`$9XD0A=)TUF8/'T0``&>+4`B#P`1GB1"%TG7R
MZ\!$C2T"+0``08G?9@\?1```,<!,B?Y,B>_H\_+__TB%P'0NBU0D&(L%1(P`
M`(T$D&>+4`1GB1"%TG369@\?1```9XM0"(/`!&>)$(72=?+KP(G81(T]NBP`
M`$B)1"0(9I!(BW0D"#'`3(G_Z*'R__](A<!T+(M4)!B+!?*+``"-!)!GBU`$
M9XD0A=)TU`\?0`!GBU`(@\`$9XD0A=)U\NO`C04++```08G?2(E$)`AFD$B+
M?"0(,<!,B?[H4?+__TB%P'0LBU0D&(L%HHL``(T$D&>+4`1GB1"%TG34#Q]`
M`&>+4`B#P`1GB1"%TG7RZ\!,B?Z-/20L``#H$O+__X7`=`U(B<9,B>\QP.BA
M]/__,<")WHT]%2P``.CR\?__A<!T$$B)QHT]%2P``#'`Z'[T__](B=Z-/1`L
M```QP.C.\?__2(G&A<!T-4R)YS'`Z%WT__^+1"0<9"L$)1@```!U0(/$*$B)
M[XTU_RL``#'`6UU!7$%=05Y!7^DR]/__,<!(B=Z-/=(K``#H@O'__X7`=,%(
MB<9,B?<QP.@1]/__Z[+H^NO__V8N#Q^$``````#S#Q[Z@^P8C3U"*P``9(L$
M)1@```")1"0,,<"-="0(Z#SQ__^%P'0P9P^V$(#Z,`^4P(32#Y3""="#\`$/
MML"+5"0,9"L4)1@```!U#X/$&,,/'X``````,<#KX^B/Z___9F8N#Q^$````
M```/'T``\P\>^H'LV````$B)="0H2(E4)#!(B4PD.$R)1"1`3(E,)$B$P'0W
M#RE$)%`/*4PD8`\I5"1P#RF<)(`````/*:0DD`````\IK"2@````#RFT)+``
M```/*;PDP````&2+!"48````B40D'#'`C80DX````$B)^HGAB40D"(U$)""^
M`0```(E$)`R+!>&)``#'!"0(````QT0D!#````!(B<?HJNS__[__````Z+#I
M__]!5+H"````,?954X'L$``!`&1$BR0E&````$2)I"0,``$`08G\B>/HE.S_
M_TB-:/](B>I(P?H_2,'J,$B-1!4`#[?`2"G02"G%#XB=````D#'22(GN1(GG
MZ&/L__](@_C_#X2;````B=ZZ"``!`$2)Y^C*Z___@_C_='J#^`=V6(U$`_@Y
MV')0C17ZB```ZQ=F9BX/'X0```````\?1```@^@!.=AR,6=(BPAG2#D*=>\I
MV$B82`'HBY0D#``!`&0K%"48````=4:!Q!```0!;74%<PP\?0`!(@>T```$`
M2(']``#__P^%9/___TC'P/_____KPXT]L"D``#'`Z$[^__^-/98I```QP.A!
M_O__Z+SI__]F9BX/'X0``````)#S#Q[Z@^P(Z#3I__^)Q^CMZ?__B<*%P'0#
M9XL0B="#Q`C#9F8N#Q^$```````/'P#S#Q[Z055!5$2-)5@I``!52(G]3(GG
M4X/L&&2+!"48````B40D##'`C70D".B_[O__A<!T!F>`.`!U)8M$)`QD*P0E
M&````'5W2(GN@\083(GG,<!;74%<05WI,?'__Y!(B<-(B>_H->K__TB)WT&)
MQ>@JZO__08U\!0+HX.K__X/L"+K_____28GH4TB)QTF)Q42-#04H``"-#04I
M``"^`0```#'`Z"7J__]86HM$)`QD*P0E&````'4%3(GNZXSHN^C__V9F+@\?
MA```````\P\>^D%7C06J)P``059F#V[0C06C*```055F#V[8C06/*```051F
M#V[@C064*```568/;NB-!7TG``!3@>Q(`0``9@]N!=:#``!F#VX-TH,``&1$
MBS0E&````$2)M"0\`0``28G^C70D+$B)1"002(G'9@]BPF8/8LLQP$F)]68/
MUD0D,&8/;@6;@P``QT0D.`````#'1"1D`````&8/8L3'1"1(`````&8/;,$/
M$40D5&8/;@5R@P``9@]BQ68/UD0D0.A7[?__A<!T"F>`.``/A<$$``#H9.?_
M_XG'Z!WH__^%P`^$!00``&>+&(7;#X3Z`P``B=_HT^C__XU\``'HBNG__V=$
M#[8#28G$08G'183`=#:-+;$G```/'T``1(G_10^VP$B)Z;K_____O@$````Q
MP(/#`4&#QP+HONC__V=$#[8#183`==1$C7PD4(T%^28``$2)[>L1#Q]``&=!
MBT<$08/'!(7`=$.)QTB)[C'`Z*?L__](B<.%P'3@9X`X`'3:2(G'Z%+M__^%
MP'3.2(G?Z`;H__]!B<"%P'5(9F8N#Q^$```````/'T``C6PD,&=$BT4`187`
M="MG08`X``^$%P,``$2)PTB)W^@,[?__A<`/A10!``!G1(M%!(/%!$6%P'75
M1(G#2(G?Z-SG__]$B>)$C272)0``2(G72(E4)`B)Q>C#Y___1(V\!00$``!$
MB?_H<^C__TF)V$V)X;X!````2(M4)`A(B00D2(G'B<6-!9\F``"-#9`F``!(
MB?M2NO____]0,<#HK>?__TB)W[[``0``Z##G__]?05B#^/]U$^@3YO__9T2+
M"$&#^1$/A?0"``!(BSPDC70D<.B(Y___B<.%P`^$?@```&=!BPY,BP0DO@$`
M```QP(L]^80``(T5XR8``.B.Y___13'M9F8N#Q^$``````"+A"0\`0``9"L$
M)1@````/A24$``"!Q$@!``!,B>A;74%<05U!7D%?PP\?@`````!(B=^#Q03H
MI>;__T&)P(7`#X2N_O__Z=[^__\/'T0``(N$)(@````E`/```#T`0```#X5K
M____BX0DC````(E$)`CH">7__SE$)`@/A5'___^+A"2(````)?\!```]P`$`
M``^%.O___T2)_^@PY___1(GNC3TY)0``2(E$)`B)1"08,<#HI^K__X7`#X1/
M`@``9T&+/DB)QNAS\?__08G'A<`/A#@"``!$B?_H,.;__X/X`W8[08U\!_R-
M-3`E``")1"0<Z*?E__^%P'4CBU0D'(/Z!`^$]@(``&=!@'P7^R\/A.D"``!F
M#Q^$``````!$C34H)```,<!$B>Y,B??H+.K__X7`#X3D`0``9P^V`(3`#X38
M`0``/#`/A-`!``!,B?>--6,D```QP.B@[/__1(TU_20``$2-/>0D``#H'>7_
M_T%6NO____]-B>%03(M$)!"-#;LD```QP$B+?"08O@$```#HIN7__UA:1(ML
M)!CK/P\?1```Z!/D__]G@S@1=4'HV.3__X/#`8/L"$2)^4%638GA08GHNO__
M__]3O@$```!,B>]0,<#H8>7__X/$(+[``0``3(GOZ.'D__^#^/]TM$B+/"3H
M0^/__TB+7"0(2(M\)!`QP$B)WNCOZ___2(G?Z%?Z___IXOW__V:013'`Z0']
M__\/'X0``````(UL)$!%B>QF#Q^$``````!GBWT`A?]T(DR)YC'`Z`[I__](
MB<>%P'0&9X`X`'4Q9XM]!(/%!(7_==Z_#0```(T=<B,``.A6Y?__0;A3````
M28G$08G'Z<O[__\/'T0``.A+Y/__@\4$B<.%P'2B2(G'Z&KD__^-?``!Z9+[
M__]G08L.3(L$)+X!````,<"+/1R"``"-%<8C``#HL>3__^D>_?__#Q]``$B)
MQTB)P^B-^?__BX0D/`$``&0K!"48````#X5"`0``@<1(`0``2(G?6UU!7$%=
M05Y!7^G0X___9T6+/NF__?__#Q^``````$2)_S'V,<#H9.+__T&)Q87`#X09
M_O__B<?HXO?__TF)QTB%P`^(!O[__S'22(UP]D2)[^B(Y/__C;0D"@$``+H&
M````1(GOZ/3C__^#^`8/A<H```"!O"0*`0```$-!0P^%ROW__V:!O"0.`0``
M2$4/A;K]__\QTDF-=\Z-G"00`0``1(GOZ#7D__^Z*````$B)WD2)[^BEX___
M@_@H=7^-!9XB``"-#6DB``"^`0```,:$)#@!````4$V)X;K_____,<!33(M$
M)!!(BWPD&.A,X___65Y$BVPD&.GT_?__9T6+=@1%A?8/A!+]__]$B??H^N+_
M_X/X`P^&`?W__T&-?`;\C37[(0``Z''B__^%P$4/1/[IYOS__^BQX?__C3WE
M(0``,<#H)/;__P\?0`#S#Q[Z05:-/=<@``!!54%455.#[!!D1(LL)0````!D
M1(LD)1@```!$B60D#$R+)?U_``"-="0(2(GU1(G@1`'H9XL89P^V0VAGB$-I
M,<#HO>;__X7`=`IG@#@Q#X17`0``,<#H^/#__V=#BUPE`(G?N0,```"Z`0``
M`(TUDR$``.C;X/__B<.%P'0M9XM`$$>-="4`C15[(0``9T&+/F>+,.CJX/__
M9XM#$&>+,&?V1@I`#X4X`0``0XU<)0"Y`P```+H!````9XL[C35*(0``Z(O@
M__]!B<:%P'0JB>Z-/<T?```QP.@EYO__2(G"9T&+1A!GBS"%T@^$T@```&>+
M.^B*X/__0XU<)0"Z`0```(TU!B$``&>+.^BBW___9XL[C14*(0``2(G&Z&'@
M__]GBP.)[HT];A\``&?&0&D`,<#HRN7__XD%4'\``(G"A<!T/HG3OL`!``!(
MB=_H'^'__XU0`8/Z`78)@_@1#X6,````BT0D#&0K!"48````#X65````@\00
M6UU!7$%=05[#BST*?P``Z%7W__^)!?M^``")PH7`=:N-/2LA``#HCN'__V8/
M'T0``&>`>`$`#X2K_O__Z9G^__\/'X0``````(L%RGX``(GW9XL`2(G&Z/WI
M___I'O___P\?A```````9T&+/NC7X/__Z;K^__^+%9Q^``")P8T]]"```#'`
M9XLR2(G:Z"?A___H@M___V:0\P\>^E532(G[C3W0'@``@^P89(L$)1@```")
M1"0,,<"-="0(Z,?D__^%P'0>9P^V$(32#Y3`@/HP#Y3""-!U"TB%VW0&9X`[
M`'45BT0D#&0K!"48````=6"#Q!A;7<.02(G?Z*CM__^^+P```$B)QTB)Q>AH
MW___C5`!A<")UP]$_>CIW___N@0```"--1D?``!(B<?H)M[__X7`=:V+1"0,
M9"L$)1@```!U#8/$&$B)WUM=Z7?E___HPM[__V:005=!5D%505154X'LF`(`
M`&2+-"48````B;0DC`(``$B)_HGBC7PD"$2-C"2(````1(U&.&9F+@\?A```
M````D&=!BP!G38L0@\<008/`"`_(B<!,B=%G2(E'Z$R)T$C!Z2!(P>@H2<'J
M."4`_P``3`G028G*2,'A"$G!XAB!X0``_P!%B=),"=!("<AG2(E'\$0YSW6J
MN_____]F#V]$)!"-1"1H9@]O7"0@9D@/;NMF#V]4)#"!PF@"``!F#VSM9_,/
M;PAF#V_B9V8/;U#8@\`09V8/[T"(9@_ORF8/[\%F#V_(9@]S\`%F#W/1'V8/
MZ\%F#]O%9P\I0`AF#V_#9@]OW#G0=;EG3(L.9TR+7A!GBWX@9TB+7AA,B<A,
MB<IG2(MN"$B+3"0(2,'J&TC!X`5("=`#!"1(C8P+F7F"6HV4.)EY@EI,B=A(
M,=A((>A(,=B-/`)(B>I(B>A(P>@"2,'B'DF)^D@)PDR)V$G!ZAM!B=!,,<!,
M(<A,,=A(`<A(B?E(P>$%3`G13(M4)!!$C20(3(G(3(G)2,'I`DC!X!Y/C903
MF7F"6DV)Y4@)R$G![1M(,<*)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD&$$!
MTDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=")UTPAX$G![1M(,<A,
M`<!-B=!)P>`%30GH3(ML)"!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@
M38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD*`'13(G22<'J
M`DC!XAZ)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!
MYP5,">],BVPD,`''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M
M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q,BVPD.$$!U$B)RDC!Z0)(P>(>18GD
M3XV4*IEY@EI("<I-B>5(,=!)P>T;B=%((?A,,<!,`=!-B>))P>(%30GJ3(ML
M)$!!`<)(B?A(P>\"2,'@'D6)TD^-A"B9>8):2`GX38G52#'"2<'M&XG'3"'B
M2#'*3`'"38G02<'@!4T)Z$R+;"1(00'03(GB2<'L`DC!XAY%B<!*C8PIF7F"
M6DP)XDV)Q4@QT$G![1M!B=1,(=!(,?A(`<A,B<%(P>$%3`GI3(ML)%`!P4R)
MT$G!Z@)(P>`>B<E*C;POF7F"6DP)T$F)S4@QPDG![1M!B<),(<),,>)(`?I(
MB<](P><%3`GO3(ML)%@!UTR)PDG!Z`)(P>(>B?]/C:0LF7F"6DP)PDF)_4@Q
MT$G![1M!B=!((<A,,=!,`>!)B?Q)P>0%30GL3(ML)&!!`<1(B<A(P>`>2,'I
M`D6)Y$^-E"J9>8):2`G(38GE2#'"2<'M&XG!2"'Z3#'"3`'238GB2<'B!4T)
MZDR+;"1H00'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@QT$G![1N)
MUTPAX$@QR$P!P$V)T$G!X`5-">A,BVPD<$$!P$R)X$G![`)(P>`>18G`2HV,
M*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)Z4R+;"1X
M`=%,B=)(P>(>2<'J`HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G23"'`3#'@
M2`'X2(G/2,'G!4P)[TR+K"2``````<=,B<!)P>@"2,'@'HG_3XVD+)EY@EI,
M"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$:-+")(B<I(P>D"
M3(ND)(@```!(P>(>2`G*3XV4(IEY@EI-B>Q(,=!)P>P;B=%((?A,,<!,`=!-
MB>I)P>(%30GB3(ND))````!!`<)(B?A(P>`>2,'O`D6)TD^-A""9>8):2`GX
M38G42#'"2<'L&XG'3"'J2#'*3`'"38G02<'@!4T)X$6)P$P!PDV)Z$G![0))
MP>`>08G430GH3(NL))@```!,,<!,(=!*C8PIF7F"6DV)Y4@Q^$G![1M(`<A,
MB>%(P>$%3`GIB<E(`<A,B=%)P>H"2,'A'D&)Q4P)T4V)PD6)P$DQRD0QTDR+
ME"2@````2HV\%Z'KV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG22`'73(GB2,'B
M'DG![`)!B?I,`X0DJ````$P)XDF)S(G)2`.,)+````!),=1$,>!-C:0`H>O9
M;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)X$P)Z$F)U8G2
M2`.4)+@```!),<5$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,
MB=%)P>H"2,'A'D2)[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;
M2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4@#A"3`````2`.,
M),@```!),=!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?A(
MP>\"2,'@'D6)Z$@)^$B)UXG22`.4)-````!(,<=$,>=,C:0YH>O9;DR)P4R)
MQTC![QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)-@`
M``!),<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"
M2,'B'D6)ZDP)PDF)R(G)23'02`.,).````!%,>!.C:0`H>O9;DR)T$V)T$G!
MZ!M(P>`%3`G`B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4).@```!(
M,<=$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A
M'D2)[TP)T4F)PHG`2`.$)/````!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(
MP>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'K
MV6Y,B=!-B=!(P>`%2<'H&T@#C"3X````3`G`B<!)`<5(B?A(P>\"2,'@'D6)
MZ$@)^$B)UXG22`.4)``!``!(,<=$,>=,C:0YH>O9;DR)P4R)QTC![QM(P>$%
M2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)`@!``!),<I%,>I.
MC:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B'D6)ZDP)
MPDF)R(G)23'013'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P$@#C"00`0``
MB<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4)!@!``!(,<=$,>],C:PY
MH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)
MPHG`2`.$)"`!``!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))
M`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,B=!-B=!)
MP>@;2,'@!4P)P(G`20'%2(GX2,'@'DC![P)%B>A(`XPD*`$``$@)^$B)UXG2
M2`.4)#`!``!(,<=$,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%3`GG38G42<'J
M`DG!Y!Z)_TT)U$F)PD@!^8G`2`.$)#@!``!-,>*)ST4QZDF)_4Z-E!*AZ]EN
M2(GZ2<'M&TC!X@5,">I!`=),B<))P>@"2,'B'D6)TDP)PDV)X$6)Y$DQT$F)
MUD&)U40QP4V)T$B-C`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!2(GY2,'O`KC<
MO!N/2,'A'D@)^4D)SHG/2"'Z32'620G62(N4)$`!``!(`<),`>)-B<1,`?)-
MB<9)P>0%2<'N&TT)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^
M3"'!3`GQ3(NT)$@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!
MS4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)%`!``!)`<9,
M`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)
MUD&)U$TAQDPAZ4P)\4R+M"18`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-
M"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"1@
M`0``20'&30'P38G63`'"38G02<'@!4G![AM-"?!!`=!(B?I(P>\"2,'B'D6)
MP$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)&@!``!)`<9-`?1-B<9,`>%-B<1)
MP>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G108G*20G.32'&3"'2
M3`GR3(NT)'`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDC!
MXAY)P>@"18GM3`G"2`G128G608G032'63"'A3`GQ3(NT)'@!``!)`<9,`?=-
MB>Y(`?E,B>])P>X;2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)_TP)X4&)S$D)
MSDTA[DPAXDP)\DR+M"2``0``20'&30'R28G^3`'228GZ2<'N&TG!X@5-"?)!
M`=),B>I)P>T"2,'B'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)\4R+M"2(`0``
M20'&30'P38G63`'!38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(P>\"2,'A'D6)
MP$@)^8G/20G.32'62"'Z3`GR3(NT))`!``!)`<9-`?1-B<9,`>)-B<1)P>X;
M2<'D!4T)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^3"'!3`GQ
M3(NT))@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!S4R)P4G!
MZ`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)*`!``!)`<9,`?=-B>Y(
M`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)UD&)U$TA
MQDPAZ4P)\4R+M"2H`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-"?))B=9!
M`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"2P`0``20'&
M30'P38G63`'"38G02<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B'D6)P$@)^D@)
MT4F)UHG732'N3"'13`GQ3(NT)+@!``!)`<9-`?1-B<9,`>%-B<1)P>X;2<'D
M!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G120G.08G*32'&3"'23`GR3(NT
M),`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDG!Z`)(P>(>
M18GM3`G"2`G128G008G732'03"'A3`G!3(N$),@!``!)`<!,`<=-B>A(`?E,
MB>])P>@;2,'G!4P)QT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)_$@)^4PAZ4PA
MXD@)RDB+C"30`0``2`'!3`'138G"2`.$)-@!``!(`<I,B<%)P>H;2,'A!4P)
MT8G)2`'*3(GI2<'M`DC!X1Y!B=),">E("<])B<U!B<Y,(<=-(>5)"?U*C3PX
M3(G03(N\)/@!``!,`>]-B=5(P>`%2<'M&TP)Z(G`2`''3(G`2<'H`DC!X!Y!
MB?U)"<"XUL%BRDPQP3'12(N4).`!``!(`<),`>)-B>Q(`<I,B>E)P>P;2,'A
M!4P)X4V)U(G)2<'D'D@!RDG!Z@))`<=-">)-B<2)T46)P$TQU$0QYTR+I"3H
M`0``20'$30'T28G.3`'G28G,2<'N&TG!Y`5-"?1-B>Y)P>T"2<'F'D6)Y$T)
M]4P!YTR+M"3P`0``08G\20'&30'P38G633'N1#'R38GF20'03(GB2<'N&TC!
MX@5,"?*)TDD!T$B)RDC!Z0)(P>(>18G&2`G*1(G138GJ23'23`'Y3(N\)``"
M``!$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!X1Y!
MB?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"00`@``13'H38G520'(3(G12<'M&TD!
MQTC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)`@"``!)`<9,`?)-
MB>9),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!XAY!
MB?Y)"=)$B>))B<R)R4P!^DTQU$R+O"0@`@``13'@38GT20'03(GR2<'L&TD!
MQTC!X@5,">*)TDD!T$R)ZDG![0)(P>(>18G$3`GJ3(NL)!@"``!)`<5,`>E-
MB=5),=5$,>]-B>5(`<],B>%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!X1Y!
MB?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"0P`@``13'038GJ20'(3(GI2<'J&TC!
MX05,"=&)R4D!R$R)X4C!X1Y)P>P"18G"20''3`GA3(ND)"@"``!)`<1,`>)-
MB?1),<Q$,>=-B=1(`==,B=))P>P;2,'B!4P)XHG22`'73(GJ2<'M`DC!XAY!
MB?Q)"=5$B?))B<Z)R4TQ[DP!^DR+O"1``@``13'P38GF20'03(GB2<'N&TC!
MX@5,"?*)TDD!T$R)TDG!Z@)(P>(>18G&3`G23(N4)#@"``!)`<),`=%-B>I)
M,=)$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!X1Y!
MB?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"1@`@``13'H38G520'(3(G12<'M&TC!
MX05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)$@"``!)`<9,`?)-B>9%
MB>1),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!XAY!
MB?Y)"=)(BY0D4`(``$@!PDD!U$B)RHG)3#'220''1#'"38GP20'43(GR2<'H
M&TC!X@5,"<*)TDD!U$R)ZDG![0)(P>(>18G@3`GJ3(NL)%@"``!)`<5,`>E-
MB=5),=5$,>]-B<5(`<],B<%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!X1Y!
MB?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"1P`@``13'B38GL3`'138GJ2<'L&TG!
MX@5-">)-B<1%B=))P>0>3`'12<'H`DD!QTT)X$&)RDR+I"1H`@``20'$2`.$
M)'@"``!,`>)-B?1,`<A-,<1$,>=-B=1(`==,B=))P>P;2,'B!4P)XDV)[$G!
M[0))P>0>B=)-">5%B?1-B<9(`==-,>Z)^DT!_$6)P$0Q\4F)UDP!P$V)Z$P!
MX4F)U$G![AM)P>0%30GT1`'A38G42<'J`DG!Y!Z)R4T)XDTQT$0QQTF)R$@!
M^$B)STC!YP5)P>@;`>E!`=I,"<=G1`-N(&=(B4X(`?AG3(E6&&=(B09(B=!(
MP>H"2,'@'F=,B6X@2`G01`'89TB)1A"+A"2,`@``9"L$)1@```!U$8'$F`(`
M`%M=05Q!74%>05_#Z$W(__]F9BX/'X0``````&:0\P\>^H/L"+^`````Z`_*
M__]F#V\%5T<``&=(QT`P`````&</$0!F#V\%4D<``&?'0'@`````9P\10!!F
M#V\%34<``&</$4`@@\0(PP\?0`#S#Q[Z05=)B?](8\)!5D%528GU051)B<15
M08UO.%.#[!AG2(M_*&=)BU<PC33'2#G^9TF)=RA(@](`2,'H'4@!T&=)B4<P
M9T&+1WB%P`^%%0$``$&#_#]^>T&-1"3`0<'L!DR)ZXE$)`Q!C40D_T'!Y`:)
M1"0(10'L#Q^``````&?S#V\#3(G_9P\110!G\P]O0Q!G#Q%%$&?S#V]#(&</
M$44@9_,/;T,P@\-`9P\113#H>NC__T$YW'7%BTPD#(M$)`A!B<S!X`:#X<!!
M*<1&C6PI0$&#_`AR7F=)BU4`08UW0(/F^&=)B5<X9TN+1"7X9TJ)1"7X*?5$
MB>@IZ$0!Y8/E^(/]"'(7@^7X,=)G2(L\$&=(B3P6@\((.>IR[Y!G18EG>(/$
M&%M=05Q!74%>05_##Q]$``!!]L0$=6U%A>1TW6=!#[95`&=!B%<X0?;$`G3,
M9T,/MT0E_F=F0HE$)?[KO`\?0`"[0````(U\!0!,B>XIPT0YXT$/3]R)VNC\
MQO__9T&+1W@!V&=!B4=X@_A`=9!!`=U,B?]!*=Q%B>WHBN?__^FH_O__9T&+
M50!G08E7.&=#BT0E_&="B40E_.E:____9BX/'X0``````/,/'OI!5D2-=CA!
M54%454B)_5-G3(MN*$B)\V=,BV8P3(GH2,'H`X/@/XU0`6?&1#`X@$&-#!:#
M^C@/CK@!``"X0````"G0=!PQTJ@!#X5-`@``9\8$$0!GQD01`0"#P@(YPG+N
M2(G?Z//F__]F#^_`9P\10SAG2<=&,`````!G00\11A!G00\11B!,B>)!#[;%
M3(GO3(GN2,'J&$C!X`A,B>%(P>\028G13(GJ2,'N&`^VUD`/MO]`#[;V2,'I
M$$@)T$R)X@^VR4C!X`A("?A(B=](P>`(2`GP00^V]$C!X`A("?`/MO9!#[;1
M2,'@"$@)\$C!X`A("<A(P>`(2`G09TB)0W#H5>;__V=(BP-(B=](P>@89XA%
M`&=(BP-(P>@09XA%`6=(BP-GB&4"9TB+`V>(10-G2(M#"$C!Z!AGB$4$9TB+
M0PA(P>@09XA%!6=(BT,(9XAE!F=(BT,(9XA%!V=(BT,02,'H&&>(10AG2(M#
M$$C!Z!!GB$4)9TB+0Q!GB&4*9TB+0Q!GB$4+9TB+0QA(P>@89XA%#&=(BT,8
M2,'H$&>(10UG2(M#&&>(90YG2(M#&&>(10]G2(M#($C!Z!AGB$409TB+0R!(
MP>@09XA%$6=(BT,@9XAE$F=(BT,@9XA%$UM=05Q!74%>Z7W#__\/'T0``+@X
M````,?\IT(/X"',JJ`0/A=(```"%P`^$=?[__V?&`0"H`@^$:?[__S'29V:)
M5`'^Z5S^__^0C5$(9TC'`0````!G2,=$`?@`````@^+X*=$!R(/@^(/X"`^"
M,_[__XU(_T&)P+X(````9TC'`@````#!Z0-!@^#X@^$!.<8/@P[^__^%R74_
M9TB)/#)G2(E\,@B#QA!$.<9R[>GR_?__#Q^``````+H!````9\8!`#G"#X*B
M_?__Z:_]__]F+@\?A```````9TC'0@@`````OA````!$.<9RKNFS_?__#Q^$
M``````!GQP$`````9\=$`?P`````Z9;]__]F+@\?A```````D(L-SF$``.F5
MQ/__`$B#[`A(@\0(PP``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%
M4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`'-H;W)T
M(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE
M=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8S`"UE
M`"TM`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,`````
M`````2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````
M`````````1L#._@````>````<'___T`!``#0@O__9`$``/""__\<!@``$(7_
M_Q0!```0AO__>`$``-"&___$`0``4(?__^@!``"PB/__)`(``."*__]P`@``
ML(O__ZP"````C/__R`(``#",___<`@``X(S__Q`#``#PC/__)`,```"/__^$
M`P``,(___Z`#``!@D/__V`,``+"4__\D!```()7__T`$``#0E?__6`0``/"6
M__^0!```()?__Z@$``#PE___\`0```"?__^@!0``(*'__^0%``#@H?__2`8`
M`&"X__^8!@``L+C__[`&``"`NO___`8``("]__\\!P``%``````````!>E(`
M`7@0`1L,!PB0`0<0$````!P```#T@___)``````````4``````````%Z4@`!
M>!`!&PP'")`!```@````'````"A^__]@`P````X01@X82@\+=PB``#\:.RHS
M)"(0````0````&2!__\(`````````$@```!4````D(3__[@`````0@X0CP)"
M#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'0PY``ET*#CA$#C!!#BA"#B!"#AA"
M#A!"#@A)"P`@````H`````2%__]X`````$$.$(,"1@ZP`0)J"@X000X(00LX
M````Q````&"%__]4`0```$(.$(T"0@X8C`-!#B"&!$$.*(,%1@[0`7H*#BA!
M#B!!#AA"#A!"#@A$"P!(``````$``(2&__\I`@```$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9$#CB#!T,.8`,6`0H..$$.,$$.*$(.($(.&$(.$$(."$@+
M.````$P!``!HB/__R@````!"#A"-`D<.&(P#00X@A@1*#BB#!48.P"`"9PH.
M*$$.($$.&$(.$$(."$$+&````(@!``#\B/__3P````!%#A"#`G`."````!``
M``"D`0``,(G__RT`````````,````+@!``!,B?__K@````!&#A",`D$.&(8#
M0PX@@P1&#L!``I0*#B!!#AA!#A!"#@A!"Q````#L`0``R(G__PD`````````
M7``````"``#$B?__`P(```!&#A"/`D(.&(X#0@X@C01"#BB,!40.,(8&2@XX
M@P=&#H`B`EL*#CA!#C!!#BA"#B!"#AA"#A!"#@A+"P*M#H@B2`Z0(FH.B")!
M#H`B````&````&`"``!TB___(@````!%#A"#`E@."````#0```!\`@``B(O_
M_RD!````10X0A@)!#AB#`T8.L"`"V0H.&$$.$$$."$D+5PH.&$<.$$$."$D+
M2````+0"``"`C/__1@0```!&#A"/`D(.&(X#0@X@C01"#BB,!4@.,(8&00XX
M@P=##F`#[`,*#CA,#C!!#BA"#B!"#AA"#A!"#@A%"Q@``````P``A)#__V$`
M````1PX@`DD*#@A("P`4````'`,``-B0__^P`````$H.X`$````T````-`,`
M`'"1__\4`0```$(.$(P"2`X8A@-!#B"#!$8.L(`$`KX*#B!!#AA!#A!"#@A%
M"P```!0```!L`P``6)+__R(`````1PX06@X(`$0```"$`P``<)+__\4`````
M1@X0C0)"#AB,`T@.((8$1PXH@P5##D!U"@XH1@X@00X80@X00@X(1@MC#DA)
M#E!@#DA!#D```*P```#,`P``^)+__PP'````1@X0CP)(#AB.`TP.((T$3`XH
MC`5+#C"&!DL..(,'1@Z``P,$`@Z(`T8.D`-5#H@#0@Z``P)X"@XX1`XP00XH
M0@X@0@X80@X00@X(2`L#10$.B`-)#I`#70Z(`T$.@`-B#H@#10Z0`TP.F`-)
M#J`#2@Z``P,<`0H..$0.,$$.*$(.($(.&$(.$$(."$4+`LH.B`-+#I`#4`Z(
M`T$.@`,`0````'P$``!8F?__'@(```!&#A".`D@.&(T#0@X@C`1!#BB&!4$.
M,(,&0PY``W(!"@XP00XH00X@0@X80@X00@X(00LT````P`0``#2;__^^````
M`$4.$(8"00X8@P-,#C`"2@H.&$$.$$$."$(+`D\*#AA$#A!!#@A%"R@```#X
M!```S'S__QP"````10X0A@)!#AB#`T,.0`-?`0H.&$,.$$$."$$+3````"0%
M``"0F___<Q8```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=&#M`%
M`U,6"@XX00XP00XH0@X@0@X80@X00@X(00L````4````=`4``,"Q__],````
M`$<.$`)$#@A(````C`4``/BQ___&`0```$8.$(\"2`X8C@-"#B"-!$4.*(P%
M1`XPA@9%#CB#!T,.4`,'`0H..$$.,$$.*$(.($(.&$(.$$(."$8+/````-@%
M``!\L___]0(```!&#A".`D8.&(T#0@X@C`1!#BB&!40.,(,&`]0!"@XH00X@
M0@X80@X00@X(2@L``!`````8!@``/+;__PL```````````````0````0````
M`0```$=.50```````P````0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"@)@``8"8``$YA```&80``Z6``
M`%]A```````````````````````````````````````````````````!````
MY`(```$```#T`@``#``````@```-````/%X``!D```"XO```&P````0````:
M````O+P``!P````$````]?[_;S`"```%````!`D```8````D`P``"@```$\$
M```+````$````!4``````````P```/B]```"````?`(``!0````'````%P``
M`$P/```'````4`X```@```#\````"0````P````>````"````/O__V\!```(
M_O__;Q`.``#___]O`0```/#__V]4#0``^?__;P@`````````````````````
M`````````````````````````````````````````/2\````````````````
M`````````````#8@````````1B````````!6(````````&8@````````=B``
M``````"&(````````)8@````````IB````````"V(````````,8@````````
MUB````````#F(````````/8@````````!B$````````6(0```````"8A````
M````-B$```````!&(0```````%8A````````9B$```````!V(0```````(8A
M````````EB$```````"F(0```````+8A````````QB$```````#6(0``````
M`.8A````````]B$````````&(@```````!8B````````)B(````````V(@``
M`````$8B````````5B(```````!F(@```````'8B````````AB(```````"6
M(@```````*8B````````MB(```````#&(@```````-8B````````YB(`````
M``#V(@````````8C````````%B,````````F(P```````#8C````````1B,`
M``````!6(P```````&8C````````=B,`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````!,````I005(N<&T*`````/AB``!'0T,Z("A$96)I
M86X@,30N,BXP+3$W*2`Q-"XR+C```"YS:'-T<G1A8@`N;F]T92YG;G4N8G5I
M;&0M:60`+FYO=&4N9VYU+G!R;W!E<G1Y`"YI;G1E<G``+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YN;W1E+D%"22UT86<`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A=&$N<F5L+G)O`"YD>6YA;6EC
M`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````
M``````````````````````````L````'`````@```-0!``#4`0``)```````
M````````!``````````>````!P````(```#X`0``^`$``!P`````````````
M``0`````````,0````$````"````%`(``!0"```:```````````````!````
M`````#D```#V__]O`@```#`"```P`@``]`````4`````````!`````0```!#
M````"P````(````D`P``)`,``.`%```&`````0````0````0````2P````,`
M```"````!`D```0)``!/!``````````````!`````````%,```#___]O`@``
M`%0-``!4#0``O`````4``````````@````(```!@````_O__;P(````0#@``
M$`X``$`````&`````0````0`````````;P````0````"````4`X``%`.``#\
M````!0`````````$````#````'D````$````0@```$P/``!,#P``?`(```4`
M```8````!`````P```"#`````0````8`````(````"```!<`````````````
M``0`````````?@````$````&````("```"`@``!@`P`````````````0````
M$````(D````!````!@```(`C``"`(P``"```````````````"`````@```"2
M`````0````8```"@(P``H",``)LZ`````````````"``````````F`````$`
M```&````/%X``#Q>```)```````````````$`````````)X````!`````@``
M``!@````8```L$``````````````$`````````"F`````0````(```"PH```
ML*```/P```````````````0`````````M`````$````"````K*$``*RA``!8
M!@`````````````$`````````+X````'`````@````2H```$J```(```````
M````````!`````````#,````#@````,```"XO```N*P```0`````````````
M``0````$````V`````\````#````O+P``+RL```$```````````````$````
M!````.0````!`````P```,"\``#`K```,P``````````````(`````````#Q
M````!@````,```#TO```]*P````!```&``````````0````(````C0````$`
M```#````^+T``/BM```(`@`````````````(````"````/H````!`````P``
M``#`````L```&```````````````"````````````0``"`````,````@P```
M&+```#@``````````````"``````````!0$```$````P`````````!BP```?
M```````````````!`````0````$````#```````````````WL```#@$`````
.`````````0``````````
